@@ -26,7 +26,7 @@
 ##  shiela-install.sh: repository install program (syntax: Bourne-Shell)
 ##
 
-version="1.1.3"
+version="1.1.4"
 
 prefix="@prefix@"
 bindir="@bindir@"
@@ -372,10 +372,10 @@ else
     CVS_VENDOR=CVSHome.org
 fi
 case $CVS_VERSION in
-   1.1[2-9]* )
+   1.12.[6-9] | 1.12.[1-9][0-9] | 1.1[3-9].* )
        ;;
    * )
-       echo "ERROR: CVS has to be at least version 1.12"
+       echo "ERROR: CVS has to be version 1.12.6 or higher"
        exit 1
        ;;
 esac
