@@ -26,7 +26,7 @@
 ##  shiela.pl: control program (syntax: Perl)
 ##
 
-my $version = '1.1.3';
+my $version = '1.1.4';
 
 require 5.005;
 
@@ -1662,7 +1662,7 @@ sub hook_loginfo_collect {
 
         #   determine commit date
         my $ID = 0;
-        if ($rcslog =~ m|\ndate:\s+(\d\d\d\d)/(\d\d)/(\d\d)\s+(\d\d):(\d\d):(\d\d);|s) {
+        if ($rcslog =~ m|\ndate:\s+(\d\d\d\d)[/-](\d\d)[/-](\d\d)\s+(\d\d):(\d\d):(\d\d)(?:\s+[+-]?\d+)?;|s) {
             my ($Y,$M,$D,$h,$m,$s) = ($1,$2,$3,$4,$5,$6);
             $ID = POSIX::mktime($s, $m, $h, $D, $M-1, $Y-1900);
         }
